@@ -33,10 +33,11 @@ use File::Basename;
 use Getopt::Long;
 use Carp;
 use Clone 'clone';
+use YAML::XS 'LoadFile';
 
 use App::Aphra::File;
 
-our $VERSION = '0.0.6';
+our $VERSION = '0.0.7';
 
 has commands => (
   isa => 'HashRef',
@@ -93,9 +94,28 @@ sub _build_config {
   for (keys %defaults) {
     $config{$_} = $opts{$_} // $defaults{$_};
   }
+
   return \%config;
 }
 
+has site_vars => (
+  isa => 'HashRef',
+  is  => 'ro',
+  lazy_build => 1,
+);
+
+sub _build_site_vars {
+  my $self = shift;
+
+  my $site_vars = {};
+
+  if (-f 'site.yml') {
+    $site_vars = LoadFile('site.yml');
+  }
+
+  return $site_vars;
+}
+
 has include_path => (
   isa => 'ArrayRef',
   is  => 'ro',
@@ -134,6 +154,9 @@ sub _build_template {
         OUTPUT_FORMAT => $self->config->{output},
       ),
     ],
+    VARIABLES    => {
+      site => $self->site_vars,
+    },
     INCLUDE_PATH => $self->include_path,
     OUTPUT_PATH  => $self->config->{target},
     WRAPPER      => $self->config->{wrapper},
@@ -220,7 +243,7 @@ Dave Cross <dave@perlhacks.com>
 
 =head1 COPYRIGHT AND LICENCE
 
-Copyright (c) 2017, Magnum Solutions Ltd. All Rights Reserved.
+Copyright (c) 2017-2023, Magnum Solutions Ltd. All Rights Reserved.
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
